'use strict';

/**
 * Shorten a string upto a maximum length of characters and add `...` as suffix if it exceeds the maximum length
 * @param str The The string you want to shorten
 * @param maxLength Maximum length of character
 * @returns Formatted shortedned string
 */
const shorten = (str, maxLength = 20) => {
    if (str == null)
        return '';
    if (str.length > maxLength) {
        return `${str.substring(0, maxLength)}...`;
    }
    return str;
};
/**
 * Checks if a given string consists of only emojis.
 *
 * However this classifies a string with numbers as emoji as well.
 * Which works in our favour for now in chat as it enlarges messages with just numbers.
 * @param str String on which to perform the check on
 * @returns A Boolean value which indicates if string consists of only emojis
 */
const hasOnlyEmojis = (str) => {
    const num = /^\d+$/;
    const re = /^\p{Emoji}+$/u;
    return re.test(str) && !num.test(str);
};
const sanitizeLink = (link) => {
    // TODO: needs more work
    if (link === null || link === void 0 ? void 0 : link.trim().toLowerCase().startsWith('javascript:')) {
        return 'https://dyte.io';
    }
    return link;
};
/**
 * Formats a given name and returns **Participant** for unnamed participants.
 * @param name Name of participant
 * @returns Name to use in the UI
 */
const formatName = (name) => {
    name = name === null || name === void 0 ? void 0 : name.trim();
    if (name === '')
        return 'Participant';
    return name;
};
const whiteSpace = new RegExp(/[^\u00BF-\u1FFF\u2C00-\uD7FF\w\s]/, 'g');
const space = new RegExp(/\s+/);
function getInitials(name, maxInitials = 2) {
    // removes any character that is not a letter, number or whitespace
    const cleanedName = name.replace(whiteSpace, '');
    const words = cleanedName.trim().split(space).slice(0, maxInitials);
    return words
        .map((word) => word.charAt(0))
        .join('')
        .toUpperCase();
}

exports.formatName = formatName;
exports.getInitials = getInitials;
exports.hasOnlyEmojis = hasOnlyEmojis;
exports.sanitizeLink = sanitizeLink;
exports.shorten = shorten;
