import { p as proxyCustomElement, H, h, e as Host } from './p-c3592601.js';
import { a as defaultIconPack, c as useLanguage } from './p-fc4484ae.js';
import './p-a83ccdbd.js';
import { S as SyncWithStore } from './p-989a34c9.js';
import { R as Render } from './p-60fdbd75.js';

const rtkAudioGridCss = ":host{line-height:initial;font-family:var(--rtk-font-family, sans-serif);font-feature-settings:normal;font-variation-settings:normal}p{margin:var(--rtk-space-0, 0px);padding:var(--rtk-space-0, 0px)}.scrollbar{scrollbar-width:thin;scrollbar-color:var(--rtk-scrollbar-color, rgb(var(--rtk-colors-background-600, 60 60 60)))\n    var(--rtk-scrollbar-background, transparent)}.scrollbar::-webkit-scrollbar{height:var(--rtk-space-1\\.5, 6px);width:var(--rtk-space-1\\.5, 6px);border-radius:9999px;background-color:var(--rtk-scrollbar-background, transparent)}.scrollbar::-webkit-scrollbar-thumb{border-radius:9999px;background-color:var(--rtk-scrollbar-color, rgb(var(--rtk-colors-background-600, 60 60 60)))}:host{position:relative;height:100%;width:100%;box-sizing:border-box}.content{position:relative;display:flex;height:100%;width:100%;flex-direction:column;overflow-y:auto}.waitlist-area{display:flex;flex-direction:column;--tw-bg-opacity:1;background-color:rgba(var(--rtk-colors-background-800, 30 30 30) / var(--tw-bg-opacity))}.listening-title{text-align:center;margin-top:var(--rtk-space-5, 20px);margin-bottom:var(--rtk-space-4, 16px)}.waitlist-grid{flex:1 1 0%}.grid{box-sizing:border-box;flex:1 1 0%;gap:var(--rtk-space-6, 24px);display:flex;align-content:center;justify-content:center;flex-wrap:wrap}:host([size='md']) .grid{gap:var(--rtk-space-4, 16px)}:host([size='sm']) .grid{gap:var(--rtk-space-3, 12px)}rtk-audio-tile{aspect-ratio:1 / 1;flex:none;width:calc(20%);max-width:var(--rtk-space-48, 192px);transition:all 0.3s}rtk-audio-tile[size='md']{width:100%;max-width:var(--rtk-space-36, 144px)}rtk-audio-tile[size='sm']{width:100%;max-width:var(--rtk-space-24, 96px)}";
const RtkAudioGridStyle0 = rtkAudioGridCss;

var __decorate = (undefined && undefined.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
        r = Reflect.decorate(decorators, target, key, desc);
    else
        for (var i = decorators.length - 1; i >= 0; i--)
            if (d = decorators[i])
                r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
const RtkAudioGrid$1 = /*@__PURE__*/ proxyCustomElement(class RtkAudioGrid extends H {
    constructor() {
        super();
        this.__registerHost();
        this.__attachShadow();
        /** Icon Pack */
        this.iconPack = defaultIconPack;
        /** Language */
        this.t = useLanguage();
        /** Whether to hide self in the grid */
        this.hideSelf = false;
        this.activeParticipants = [];
        this.onStageParticipants = [];
        this.offStageParticipants = [];
        this.onParticipantListUpdate = () => {
            if (!this.meeting) {
                return;
            }
            let activeParticipants = this.meeting.participants.active.toArray();
            if (!this.hideSelf) {
                activeParticipants = [...activeParticipants, this.meeting.self];
            }
            let onStageParticipants = this.meeting.participants.joined
                .toArray()
                .filter((p) => !activeParticipants.some((a) => a.id === p.id));
            this.activeParticipants = activeParticipants;
            this.onStageParticipants = onStageParticipants;
        };
    }
    connectedCallback() {
        this.meetingChanged(this.meeting);
    }
    meetingChanged(meeting) {
        if (!meeting || meeting.self.config.viewType !== 'AUDIO_ROOM') {
            return;
        }
        this.onParticipantListUpdate();
        // listeners
        meeting.participants.active.addListener('participantJoined', this.onParticipantListUpdate);
        meeting.participants.active.addListener('participantLeft', this.onParticipantListUpdate);
        meeting.participants.joined.addListener('participantJoined', this.onParticipantListUpdate);
        meeting.participants.joined.addListener('participantLeft', this.onParticipantListUpdate);
    }
    disconnectedCallback() {
        this.resizeObserver.disconnect();
        this.resizeObserver = undefined;
        this.meeting.participants.active.removeListener('participantJoined', this.onParticipantListUpdate);
        this.meeting.participants.active.removeListener('participantLeft', this.onParticipantListUpdate);
        this.meeting.participants.joined.removeListener('participantJoined', this.onParticipantListUpdate);
        this.meeting.participants.joined.removeListener('participantLeft', this.onParticipantListUpdate);
    }
    renderGrid(participants = []) {
        const defaults = {
            meeting: this.meeting,
            size: this.size,
            config: this.config,
            t: this.t,
            iconPack: this.iconPack,
            states: this.states,
        };
        return participants.map((participant) => {
            return (h(Render, { element: "rtk-audio-tile", defaults: defaults, props: {
                    key: participant.id,
                    participant,
                }, childProps: {
                    participant,
                }, deepProps: true }));
        });
    }
    render() {
        const onStage = this.activeParticipants.concat(this.onStageParticipants);
        return (h(Host, { key: '0547c2c61b1c1b1fc4fcc5353b9094f8c118bd83' }, h("div", { key: '46dd0248db3437461bd56bd507a2f42ce05af03a', class: "content scrollbar" }, h("div", { key: '98a3dc4928c3062f3e5058b50d415f147c273c26', class: "stage grid" }, this.renderGrid(onStage)), this.offStageParticipants.length > 0 && (h("div", { key: '18015fe551647048c990f107ba313c5e13ba7d47', class: "waitlist-area" }, h("div", { key: '50a65d4f48d94426860d808ff6151d3e0d519f4e', class: "listening-title" }, this.offStageParticipants.length, " ", this.t('grid.listening')), h("div", { key: '173e4ebc97425b7298236673122f76ebfae59609', class: "waitlist-grid grid" }, this.renderGrid(this.offStageParticipants))))), h("slot", { key: 'c92a12329a9c4c456f3506cee2aa2d73dceaa0e0' })));
    }
    get host() { return this; }
    static get watchers() { return {
        "meeting": ["meetingChanged"]
    }; }
    static get style() { return RtkAudioGridStyle0; }
}, [1, "rtk-audio-grid", {
        "meeting": [16],
        "config": [16],
        "states": [16],
        "iconPack": [16],
        "size": [513],
        "t": [16],
        "hideSelf": [4, "hide-self"],
        "activeParticipants": [32],
        "onStageParticipants": [32],
        "offStageParticipants": [32]
    }, undefined, {
        "meeting": ["meetingChanged"]
    }]);
__decorate([
    SyncWithStore()
], RtkAudioGrid$1.prototype, "meeting", void 0);
__decorate([
    SyncWithStore()
], RtkAudioGrid$1.prototype, "states", void 0);
__decorate([
    SyncWithStore()
], RtkAudioGrid$1.prototype, "iconPack", void 0);
__decorate([
    SyncWithStore()
], RtkAudioGrid$1.prototype, "size", void 0);
__decorate([
    SyncWithStore()
], RtkAudioGrid$1.prototype, "t", void 0);
function defineCustomElement$1() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["rtk-audio-grid"];
    components.forEach(tagName => { switch (tagName) {
        case "rtk-audio-grid":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, RtkAudioGrid$1);
            }
            break;
    } });
}
defineCustomElement$1();

const RtkAudioGrid = RtkAudioGrid$1;
const defineCustomElement = defineCustomElement$1;

export { RtkAudioGrid, defineCustomElement };
