import { p as proxyCustomElement, H, d as createEvent, h, e as Host } from './p-c3592601.js';
import { d as defaultConfig, n as uiState, u as uiStore } from './p-fc4484ae.js';
import { g as generateConfig, p as provideRtkDesignSystem, d as deepMerge } from './p-31f1e8e5.js';
import './p-a83ccdbd.js';
import { g as getSize } from './p-96be234f.js';

const rtkUiProviderCss = "rtk-ui-provider{display:block;width:100%;height:100%}";
const RtkUiProviderStyle0 = rtkUiProviderCss;

const LEAVE_ROOM_TIMER = 10000;
const RtkUiProvider$1 = /*@__PURE__*/ proxyCustomElement(class RtkUiProvider extends H {
    constructor() {
        super();
        this.__registerHost();
        this.statesUpdate = createEvent(this, "rtkStatesUpdate", 7);
        /** Config */
        this.config = defaultConfig;
        /** Whether to show setup screen or not */
        this.showSetupScreen = false;
        /**
         * Do not render children until meeting is initialized
         * @default false
         */
        this.noRenderUntilMeeting = false;
        this.handleResize = () => {
            this.size = getSize(this.host.clientWidth);
        };
        this.loadTheme = () => {
            var _a;
            if (this.config === defaultConfig) {
                const { config } = generateConfig(this.meeting.self.config, this.meeting);
                this.config = config;
            }
            if ((_a = this.config) === null || _a === void 0 ? void 0 : _a.designTokens) {
                provideRtkDesignSystem(document.documentElement, this.config.designTokens);
            }
        };
        this.roomJoinedListener = () => {
            this.updateStates({ meeting: 'joined' });
        };
        this.waitlistedListener = () => {
            this.updateStates({ meeting: 'waiting' });
        };
        this.roomLeftListener = ({ state }) => {
            // Let socketConnectionUpdate listener handle this case.
            if (state === 'disconnected' || state === 'failed')
                return;
            this.updateStates({ meeting: 'ended', roomLeftState: state });
        };
        this.mediaPermissionUpdateListener = ({ kind, message }) => {
            if (['audio', 'video'].includes(kind)) {
                if ((message === 'DENIED' || message === 'SYSTEM_DENIED') &&
                    uiState.states.activeDebugger !== true) {
                    const permissionModalSettings = {
                        enabled: true,
                        kind,
                    };
                    this.updateStates({ activePermissionsMessage: permissionModalSettings });
                }
            }
        };
        this.socketConnectionUpdateListener = ({ state }) => {
            if (state === 'failed') {
                setTimeout(() => {
                    this.meeting.leave('disconnected');
                }, LEAVE_ROOM_TIMER);
            }
        };
        this.handleChangingMeeting = (destinationMeetingId) => {
            this.updateStates({
                activeBreakoutRoomsManager: Object.assign(Object.assign({}, uiState.states.activeBreakoutRoomsManager), { destinationMeetingId }),
            });
        };
    }
    listenState(e) {
        this.updateStates(e.detail);
    }
    updateStates(states) {
        const newStates = Object.assign({}, uiState.states);
        uiState.states = deepMerge(newStates, states);
        this.statesUpdate.emit(uiState.states);
    }
    connectedCallback() {
        if (typeof window !== 'undefined') {
            this.authErrorListener = (ev) => {
                if (ev.detail.message.includes('401')) {
                    this.updateStates({ meeting: 'ended', roomLeftState: 'unauthorized' });
                }
            };
            window.addEventListener('rtkError', this.authErrorListener);
        }
        this.onMeetingChange(this.meeting);
        this.onIconPackChange(this.iconPack);
        this.onTChange(this.t);
        this.onConfigChange(this.config);
        this.onSizeChange(this.size);
        this.resizeObserver = new ResizeObserver(() => this.handleResize());
        this.resizeObserver.observe(this.host);
    }
    disconnectedCallback() {
        this.resizeObserver.disconnect();
        window.removeEventListener('rtkError', this.authErrorListener);
        if (!this.meeting)
            return;
        this.meeting.self.removeListener('roomLeft', this.roomLeftListener);
        this.meeting.self.removeListener('roomJoined', this.roomJoinedListener);
        this.meeting.self.removeListener('waitlisted', this.waitlistedListener);
        this.meeting.self.removeListener('mediaPermissionUpdate', this.mediaPermissionUpdateListener);
        this.meeting.meta.removeListener('socketConnectionUpdate', this.socketConnectionUpdateListener);
    }
    onMeetingChange(meeting) {
        uiStore.state.meeting = meeting;
        if (!meeting)
            return;
        this.updateStates({ viewType: meeting.meta.viewType });
        this.loadTheme();
        meeting.self.addListener('roomJoined', this.roomJoinedListener);
        meeting.self.addListener('waitlisted', this.waitlistedListener);
        meeting.self.addListener('roomLeft', this.roomLeftListener);
        meeting.self.addListener('mediaPermissionUpdate', this.mediaPermissionUpdateListener);
        meeting.meta.addListener('socketConnectionUpdate', this.socketConnectionUpdateListener);
        if (meeting.connectedMeetings.supportsConnectedMeetings) {
            meeting.connectedMeetings.once('changingMeeting', this.handleChangingMeeting);
        }
        if (meeting.self.roomJoined) {
            this.updateStates({ meeting: 'joined' });
        }
        else {
            if (this.showSetupScreen) {
                this.updateStates({ meeting: 'setup' });
            }
            else {
                meeting.joinRoom();
            }
        }
        window.removeEventListener('rtkError', this.authErrorListener);
    }
    onIconPackChange(newIconPack) {
        uiStore.state.iconPack = newIconPack;
    }
    onTChange(newT) {
        uiStore.state.t = newT;
    }
    onConfigChange(config) {
        uiStore.state.config = config;
    }
    onSizeChange(newSize) {
        uiStore.state.size = newSize;
    }
    render() {
        return h(Host, { key: '255d40656744b2906c20a139a1af87c66acc310a' }, this.noRenderUntilMeeting && !this.meeting ? null : h("slot", null));
    }
    get host() { return this; }
    static get watchers() { return {
        "meeting": ["onMeetingChange"],
        "iconPack": ["onIconPackChange"],
        "t": ["onTChange"],
        "config": ["onConfigChange"],
        "size": ["onSizeChange"]
    }; }
    static get style() { return RtkUiProviderStyle0; }
}, [4, "rtk-ui-provider", {
        "meeting": [16],
        "iconPack": [16],
        "t": [16],
        "config": [16],
        "size": [1537],
        "showSetupScreen": [4, "show-setup-screen"],
        "noRenderUntilMeeting": [4, "no-render-until-meeting"]
    }, [[0, "rtkStateUpdate", "listenState"]], {
        "meeting": ["onMeetingChange"],
        "iconPack": ["onIconPackChange"],
        "t": ["onTChange"],
        "config": ["onConfigChange"],
        "size": ["onSizeChange"]
    }]);
function defineCustomElement$1() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["rtk-ui-provider"];
    components.forEach(tagName => { switch (tagName) {
        case "rtk-ui-provider":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, RtkUiProvider$1);
            }
            break;
    } });
}
defineCustomElement$1();

const RtkUiProvider = RtkUiProvider$1;
const defineCustomElement = defineCustomElement$1;

export { RtkUiProvider, defineCustomElement };
