import { EventEmitter } from '../../stencil-public-runtime';
import { IconPack, Size } from '../../exports';
import { RtkI18n } from '../../lib/lang';
import type { RTKBasicParticipant, TextMessage } from '@cloudflare/realtimekit';
interface RtkText {
    type: 'text';
    message: string;
    replyTo?: TextMessage;
}
interface RtkImage {
    type: 'image';
    image: File;
    /** @deprecated use 'image' instead */
    file: File;
}
interface RtkFile {
    type: 'file';
    file: File;
}
export type RtkNewMessageEvent = RtkText | RtkImage | RtkFile;
export declare class RtkChatComposerUi {
    private $textArea;
    /** Whether user can send text messages */
    canSendTextMessage: boolean;
    /** Whether user can send file messages */
    canSendFiles: boolean;
    /** Size */
    size: Size;
    /** Icon pack */
    iconPack: IconPack;
    /** Language */
    t: RtkI18n;
    /** Whether to show emoji picker */
    disableEmojiPicker?: boolean;
    /** prefill the composer */
    prefill: {
        suggestedReplies?: string[];
        editMessage?: TextMessage;
        replyMessage?: TextMessage;
    };
    /** list of members that can be mentioned */
    members?: RTKBasicParticipant[];
    /** channel id */
    channelId?: string;
    emojiPickerActive: boolean;
    mentionQuery: string;
    focusedMemberIndex: number;
    filePreview: string;
    /** Event emitted when new message is submitted */
    onNewMessage: EventEmitter<RtkNewMessageEvent>;
    /** Event emitted when message is edited */
    onEditMessage: EventEmitter<{
        id: string;
        message: string;
        channelId?: string;
    }>;
    /** Event emitted when message editing is cancelled */
    onEditCancelled: EventEmitter;
    private fileReader;
    private fileToUpload;
    connectedCallback(): void;
    onChannelChanged(): void;
    componentDidRender(): void;
    get storageKey(): string;
    private handleKeyDown;
    private handleKeyUp;
    private onPaste;
    private generateFilePreview;
    private sendFile;
    private handleSendMessage;
    private cleanup;
    private handleEditMessage;
    private handleEditCancel;
    private uploadFile;
    private initializeTextField;
    private onMemberSelect;
    private getFilteredMembers;
    private cleanUpFileUpload;
    private renderFilePreview;
    private renderSuggestedReplies;
    private renderMenu;
    render(): any;
}
export {};
