import { EventEmitter } from '../../stencil-public-runtime';
import { IconPack } from '../../lib/icons';
import { RtkI18n } from '../../lib/lang';
import { Meeting } from '../../types/rtk-client';
import { Size, States } from '../../types/props';
import { ControlBarVariant } from '../rtk-controlbar-button/rtk-controlbar-button';
/**
 * A button which toggles visibility of chat.
 *
 * You need to pass the `meeting` object to it to see the unread messages count badge.
 *
 * When clicked it emits a `rtkStateUpdate` event with the data:
 *
 * ```ts
 * { activeSidebar: boolean; sidebar: 'chat' }
 * ```
 */
export declare class RtkChatToggle {
    unreadMessageCount: number;
    /** Variant */
    variant: ControlBarVariant;
    /** Meeting object */
    meeting: Meeting;
    /** States object */
    states: States;
    /** Size */
    size: Size;
    /** Icon pack */
    iconPack: IconPack;
    /** Language */
    t: RtkI18n;
    chatActive: boolean;
    canViewChat: boolean;
    /**
     * Only used when paginated chat is enabled
     */
    hasNewMessages: boolean;
    connectedCallback(): void;
    disconnectedCallback(): void;
    meetingChanged(meeting: Meeting): void;
    statesChanged(states: States): void;
    private onChatUpdate;
    /** Emits updated state data */
    stateUpdate: EventEmitter<States>;
    private toggleChat;
    private updateCanView;
    handleChatActiveChange(): void;
    private buttonEl;
    render(): any;
}
